@@ -16,7 +16,7 @@ use base qw(Lemonldap::NG::Handler::SharedConf);
 use utf8;
 no utf8;
 
-our $VERSION = '1.1.2';
+our $VERSION = '1.2.2_01';
 
 # We need just this constant, that's why Portal is 'required' but not 'used'
 *PE_OK = *Lemonldap::NG::Portal::SharedConf::PE_OK;
@@ -54,29 +54,39 @@ sub run ($$) {
     my ( $id, $user, $pass );
     unless ( $user = lmHeaderIn( $apacheRequest, 'Authorization' ) ) {
         lmSetErrHeaderOut( $apacheRequest,
-            'WWW-Authenticate' => 'Basic realm="Lemonldap::NG"' );
+            'WWW-Authenticate' => 'Basic realm="LemonLDAP::NG"' );
         return AUTH_REQUIRED;
     }
     $user =~ s/^Basic\s*//;
 
     # DEBUG
-    $class->lmLog( "user: $user", 'debug' );
     $id = md5_base64($user);
 
     # II - recover the user datas
     #  2.1 search if the user was the same as previous (very efficient in
     #      persistent connection).
-    unless ( $id eq $datas->{_session_id} ) {
+    unless ( $id eq $datas->{_cache_id} ) {
 
         # 2.2 search in the local cache if exists
         unless ( $refLocalStorage and $datas = $refLocalStorage->get($id) ) {
 
             # 2.3 Authentication by Lemonldap::NG::Portal using SOAP request
+
+            # Add client IP as X-Forwarded-For IP in SOAP request
+            my $xheader = lmHeaderIn( $apacheRequest, 'X-Forwarded-For' );
+            $xheader .= ", " if ($xheader);
+            $xheader .= $apacheRequest->connection->remote_ip;
+            my $soapHeaders =
+              HTTP::Headers->new( "X-Forwarded-For" => $xheader );
+
             my $soap =
-              SOAP::Lite->proxy( $class->portal() )
+              SOAP::Lite->proxy( $class->portal(),
+                default_headers => $soapHeaders )
               ->uri('urn:Lemonldap::NG::Common::CGI::SOAPService');
             $user = decode_base64($user);
             ( $user, $pass ) = ( $user =~ /^(.*?):(.*)$/ );
+            $class->lmLog( "AuthBasic authentication for user: $user",
+                'debug' );
             my $r = $soap->getCookies( $user, $pass );
             my $cv;
 
@@ -89,12 +99,14 @@ sub run ($$) {
                 my $res = $r->result();
 
                 # If authentication failed, display error
-                if ( $res->{error} ) {
+                if ( $res->{errorCode} ) {
                     $class->lmLog(
-                        "Authentication failed for $user "
-                          . $soap->error( 'fr', $res->{error} )->result(),
+                        "Authentication failed for $user: "
+                          . $soap->error( $res->{errorCode}, 'en' )->result(),
                         'notice'
                     );
+                    lmSetErrHeaderOut( $apacheRequest,
+                        'WWW-Authenticate' => 'Basic realm="LemonLDAP::NG"' );
                     return AUTH_REQUIRED;
                 }
                 $cv = $res->{cookies}->{$cookieName};
@@ -113,6 +125,7 @@ sub run ($$) {
                 return $class->goToPortal($uri);
             }
             $datas->{$_} = $h{$_} foreach ( keys %h );
+            $datas->{_cache_id} = $id;
 
             # Store now the user in the local storage
             if ($refLocalStorage) {
@@ -129,18 +142,18 @@ sub run ($$) {
     # AUTHORIZATION
     return $class->forbidden($uri) unless ( $class->grant($uri) );
     $class->updateStatus( $datas->{$whatToTrace}, $apacheRequest->uri, 'OK' );
-    $class->logGranted($uri);
-
-    # ACCOUNTING
-    # 2 - Inform remote application
-    $class->sendHeaders;
+    $class->logGranted( $uri, $datas );
 
     # SECURITY
     # Hide Lemonldap::NG cookie
     $class->hideCookie;
 
     # Hide user password
-    $class->lmSetHeaderIn( $apacheRequest, Authorization => '' );
+    $class->lmUnsetHeaderIn( $apacheRequest, "Authorization");
+
+    # ACCOUNTING
+    # 2 - Inform remote application
+    $class->sendHeaders;
     OK;
 }
 
